Index: /pykota/trunk/conf/pykota.conf.sample
===================================================================
--- /pykota/trunk/conf/pykota.conf.sample (revision 903)
+++ /pykota/trunk/conf/pykota.conf.sample (revision 919)
@@ -99,4 +99,9 @@
 #     requester: external(npadmin --pagecount %(printer)s)
 #
+# Another example, for AppleTalk printers which works fine :
+# (You need the pap CUPS backend installed, and copy the 
+# pagecount.ps file from untested/netatalk into /etc)
+#     requester: external(/usr/bin/pap -p "%(printer)s:LaserWriter" /etc/pagecount.ps  2>/dev/null | grep -v status | grep -v Connect)
+#
 # This value can be set either globally or per printer or both.
 # If both are defined, the printer option has priority.
Index: /pykota/trunk/README
===================================================================
--- /pykota/trunk/README (revision 900)
+++ /pykota/trunk/README (revision 919)
@@ -97,14 +97,16 @@
   future. 
   
-PyKota is known to work fine with HP Laserjet 2100 and 2200   
-networked printers, and should work with any SNMP-enabled 
-network printer capable of outputing its lifetime printed pages 
-number.
-
-If your printers don't support SNMP, then making them work with 
-PyKota is up to you. Some sample scripts which can query non-SNMP 
-printers for their lifetime page counter are included in the 
-./untested directory. You'll have to test and adapt them though, and 
-define them as external requesters in the PyKota configuration file. 
+PyKota is known to work fine with HP Laserjet 2100 and 2200, and 
+Apple LaserWriter 16/600 PS. 
+
+It should also work fine with any printer capable of outputing 
+its lifetime printed pages counter via either SNMP or AppleTalk. 
+
+If your printers don't support SNMP or AppleTalk, then making them 
+work with PyKota is up to you. Some sample scripts which can query 
+non-SNMP printers for their lifetime page counter are included in 
+the ./untested directory. You'll have to test and adapt them though, 
+and define them as external requesters in the PyKota configuration 
+file. See the sample configuration file to learn how to do that.
 
 ============================================================
@@ -130,5 +132,8 @@
     - PostgreSQL's PygreSQL Python extension and the PostgreSQL client
       libraries.
-    - SNMP tools (specifically the snmpget command)
+    - SNMP tools (specifically the snmpget command) if you plan to
+      request your printer's lifetime page counter via SNMP.
+    - Netatalk (specifically the pap command) if you plan to
+      request your printer's lifetime page counter via AppleTalk.
     
   You need to have the following tools installed on the Quota Storage  
Index: /pykota/trunk/NEWS
===================================================================
--- /pykota/trunk/NEWS (revision 917)
+++ /pykota/trunk/NEWS (revision 919)
@@ -77,4 +77,7 @@
           
         - Some minor bugs which happened in rare situations were fixed.
+        
+        - Support for AppleTalk printers was added, see sample configuration
+          file for details.
         
     - 1.02 :

Index: /pykota/trunk/untested/netatalk/netatalk.sh
===================================================================
--- /pykota/trunk/untested/netatalk/netatalk.sh (revision 918)
+++ /pykota/trunk/untested/netatalk/netatalk.sh (revision 919)
@@ -3,8 +3,13 @@
 # $Id$
 #
 # The following was adapted from a post found on usenet, 
 # it works with my Apple LaserWriter 16/600 PS.
 # As always, YMMV.
 # 
-/usr/bin/pap -p "MyPrinter:LaserWriter" pagecount.ps 2>/dev/null | grep -v status | grep -v Connect
-
+echo Please uncomment one of the lines, adapt the script and restart.
+echo You can get AppleTalk printer\'s names with the nbplkup command.
+# /usr/bin/pap -p "RAMPAL-16/600:LaserWriter" pagecount.ps 2>/dev/null | grep -v status | grep -v Connect
+# /usr/bin/pap -p "LaserJet 2100 NT:LaserWriter" pagecount.ps 2>/dev/null | grep -v status | grep -v Connect
@@ -3,8 +3,13 @@
 # $Id$
 #
-# The following was adapted from a post found on usenet, 
-# it works with my Apple LaserWriter 16/600 PS.
+# The following was adapted from a post found on usenet.
+#
+# It works with my Apple LaserWriter 16/600 PS and with
+# my HP LasetJet 2100 TN with AppleTalk enabled.
+#
 # As always, YMMV.
 # 